@@ -74,13 +74,21 @@ class DLMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dlm/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dlm.html#DLM.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dlm/client/#close)
+        """
+
     def create_lifecycle_policy(
         self,
         *,
         ExecutionRoleArn: str,
         Description: str,
         State: SettablePolicyStateValuesType,
-        PolicyDetails: "PolicyDetailsTypeDef",
+        PolicyDetails: PolicyDetailsTypeDef,
         Tags: Mapping[str, str] = ...
     ) -> CreateLifecyclePolicyResponseTypeDef:
         """
@@ -169,7 +177,7 @@ class DLMClient(BaseClient):
         ExecutionRoleArn: str = ...,
         State: SettablePolicyStateValuesType = ...,
         Description: str = ...,
-        PolicyDetails: "PolicyDetailsTypeDef" = ...
+        PolicyDetails: PolicyDetailsTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates the specified lifecycle policy.
